You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@rocketmq.apache.org by li...@apache.org on 2022/03/10 09:10:42 UTC

[rocketmq-apis] branch main updated: Rename ChangeInvisibleTime to ChangeInvisibleDuration (#13)

This is an automated email from the ASF dual-hosted git repository.

lizhanhui pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/rocketmq-apis.git


The following commit(s) were added to refs/heads/main by this push:
     new 382d9b2  Rename ChangeInvisibleTime to ChangeInvisibleDuration (#13)
382d9b2 is described below

commit 382d9b2807572a723e573778c06cb3c504b633e7
Author: Aaron Ai <ya...@alibaba-inc.com>
AuthorDate: Thu Mar 10 16:55:34 2022 +0800

    Rename ChangeInvisibleTime to ChangeInvisibleDuration (#13)
---
 apache/rocketmq/v1/service.proto | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/apache/rocketmq/v1/service.proto b/apache/rocketmq/v1/service.proto
index ee9a4ed..089d5a1 100644
--- a/apache/rocketmq/v1/service.proto
+++ b/apache/rocketmq/v1/service.proto
@@ -373,7 +373,7 @@ message NotifyClientTerminationResponse {
   reserved 2 to 64;
 }
 
-message ChangeInvisibleTimeRequest {
+message ChangeInvisibleDurationRequest {
   Resource group = 1;
   Resource topic = 2;
 
@@ -385,7 +385,7 @@ message ChangeInvisibleTimeRequest {
   reserved 5 to 64;
 }
 
-message ChangeInvisibleTimeResponse {
+message ChangeInvisibleDurationResponse {
   ResponseCommon common = 1;
 
   // Server may generate a new receipt handle for the message.
@@ -545,7 +545,7 @@ service MessagingService {
   // time. The message is supposed to be processed within the invisible
   // duration. If the client, which is in charge of the invisible message, is
   // not capable of processing the message timely, it may use
-  // ChangeInvisibleTime to lengthen invisible duration.
-  rpc ChangeInvisibleTime(ChangeInvisibleTimeRequest)
-      returns (ChangeInvisibleTimeResponse) {}
+  // ChangeInvisibleDuration to lengthen invisible duration.
+  rpc ChangeInvisibleDuration(ChangeInvisibleDurationRequest)
+      returns (ChangeInvisibleDurationResponse) {}
 }
\ No newline at end of file